@@ -18,4 +18,10 @@ def f2c(n):
         return c
     except TypeError:
         n = "Enter a number"
-        return n
\ No newline at end of file
+        return n
+
+def add_temp(n):
+    a = f2c(n)
+    b = c2f(n)
+    r = a+b
+    return r
\ No newline at end of file
